QueryAborted

Enum QueryAborted 

pub enum QueryAborted {
    KeyboardInterrupt,
    OocOutOfDisk,
}
Python hooks SIGINT to instead generate a KeyboardInterrupt exception. So we do the same to try and abort long-running computations and return to Python so that the Python exception can be generated.

We also use this mechanic to abort queries that run out of disk space while spilling, which can happen from anywhere in the out-of-core code, meaning there might not be a suitable PolarsResult return path.

Variants



KeyboardInterrupt



OocOutOfDisk